### R code from vignette source 'stat_methods.Rnw'

###################################################
### code chunk number 1: Initialize
###################################################
## Change options:
op <- options() ## To be able to reset settings
options("digits" = 7)
options(help_type = "html")
options("SweaveHooks" = list(fig=function()
        par(mar=c(4,4,.5,0)+.5)))
options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)



###################################################
### code chunk number 2: ThurstoneFig
###################################################
getOption("SweaveHooks")[["fig"]]()
## Thurstonian distributions:
x <- seq(-5, 5, length.out=5e2)
delta <- 2
plot(x, dnorm(x, mean=-delta/2), type = "l", col="blue", axes=FALSE,
     xlab="", ylab="")
lines(x, dnorm(x, mean=delta/2), col="red")
abline(v=c(-delta/2, delta/2), h=0)
mtext(c("0", expression(delta)), at=c(-delta/2, delta/2), side=1)
## mtext("density", side=2)
text(-4, .2, "Reference\nsamples")
text(4, .2, "Test\nsamples")


###################################################
### code chunk number 3: Difference_Dist1
###################################################
getOption("SweaveHooks")[["fig"]]()
## Difference distributions:
x <- seq(-5, 5, length.out=5e2)
tau <- local({
  x <- c(-1.5, -.5)
  x <- c(x, -x)
  x[order(x)]
})
plot(x, dnorm(x), type = "l", col="blue",
     xlab="", ylab="", axes=FALSE)
abline(v=tau, h=0)
segments(0, 0, 0, dnorm(0), lty=2)
mtext(c(expression(tau[1]), expression(tau[2]), expression(tau[3]),
        expression(tau[4])), side=1, at=tau, line=.5)
mtext(c("much less" ,"equal", "much more"), side=3,
      at=c(-3, 0, 3))
text(4, .2, "Placebo\ndistribution")


###################################################
### code chunk number 4: Difference_Dist2
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(x, dnorm(x, mean=1), type="l", col="red",
     xlab="", ylab="", axes=FALSE)
abline(v=tau, h=0)
segments(1, dnorm(0), 1, 0, lty=2)
mtext(c(expression(tau[1]), expression(tau[2]), expression(tau[3]),
        expression(tau[4])), side=1, at=tau, line=.5)
mtext(c("much less" ,"equal", "much more"), side=3,
      at=c(-3, 0, 3))
text(4, .2, "Test\ndistribution")


###################################################
### code chunk number 5: stat_methods.Rnw:329-330
###################################################
library(opair)


###################################################
### code chunk number 6: stat_methods.Rnw:335-338
###################################################
library(ordinal)
fm1 <- clm(factor(Thickness) ~ Samples, link="probit", data=NV)
summary(fm1)


###################################################
### code chunk number 7: stat_methods.Rnw:342-344
###################################################
b <- coef(summary(fm1))
(b2 <- b[5:6, 1:2] * sqrt(2))


###################################################
### code chunk number 8: stat_methods.Rnw:350-358
###################################################
alpha <- .05
z <- qnorm(1 - alpha/2)
## lower and upper for prod 568:
b2[1, 1] +  c(-z, z) * b2[1, 2]
## lower and upper for prod 841:
b2[2, 1] +  c(-z, z) * b2[2, 2]
## Both:
b2[, 1] +  b2[, 2] %*% t(c(-z, z))


###################################################
### code chunk number 9: stat_methods.Rnw:365-366
###################################################
(W <- b2[, 1] / b2[, 2])


###################################################
### code chunk number 10: stat_methods.Rnw:369-370
###################################################
2 * pnorm(abs(W), lower.tail=FALSE)


###################################################
### code chunk number 11: stat_methods.Rnw:376-377
###################################################
dp0 <- 1.5


###################################################
### code chunk number 12: stat_methods.Rnw:380-382
###################################################
(Wa <- (b2[1,1] + dp0)/b2[1, 2])
(pa <- pnorm(Wa, lower.tail=FALSE))


###################################################
### code chunk number 13: stat_methods.Rnw:386-388
###################################################
(Wb <- (b2[1,1] - dp0)/b2[1, 2])
(pb <- pnorm(Wb))


###################################################
### code chunk number 14: stat_methods.Rnw:392-393
###################################################
(pval <- max(pa, pb))


###################################################
### code chunk number 15: stat_methods.Rnw:406-407
###################################################
sessionInfo()


###################################################
### code chunk number 16: misc (eval = FALSE)
###################################################
## 


